======
 TODO
======

 * setup sphinx documentation

 * setup travic-ci

 * add ability to configure and render csspath
   - add vars from settings to global jinja environment

 * make auth checker configurable and possible to return a richer user
   object.